@@ -117,6 +117,10 @@ class PyObjectError(PydanticTypeError):
     msg_template = 'ensure this value contains valid import path: {error_message}'
 
 
+class SequenceError(PydanticTypeError):
+    msg_template = 'value is not a valid sequence'
+
+
 class ListError(PydanticTypeError):
     msg_template = 'value is not a valid list'
 
@@ -294,9 +298,33 @@ class IPvAnyAddressError(PydanticValueError):
     msg_template = 'value is not a valid IPv4 or IPv6 address'
 
 
+class IPvAnyInterfaceError(PydanticValueError):
+    msg_template = 'value is not a valid IPv4 or IPv6 interface'
+
+
+class IPvAnyNetworkError(PydanticValueError):
+    msg_template = 'value is not a valid IPv4 or IPv6 network'
+
+
 class IPv4AddressError(PydanticValueError):
     msg_template = 'value is not a valid IPv4 address'
 
 
 class IPv6AddressError(PydanticValueError):
     msg_template = 'value is not a valid IPv6 address'
+
+
+class IPv4NetworkError(PydanticValueError):
+    msg_template = 'value is not a valid IPv4 network'
+
+
+class IPv6NetworkError(PydanticValueError):
+    msg_template = 'value is not a valid IPv6 network'
+
+
+class IPv4InterfaceError(PydanticValueError):
+    msg_template = 'value is not a valid IPv4 interface'
+
+
+class IPv6InterfaceError(PydanticValueError):
+    msg_template = 'value is not a valid IPv6 interface'
